{
  config,
  pkgs,
  ...
}: {
  home = {
    username = "tbarnouin";
    stateVersion = "24.11";
    sessionPath = [
      "$HOME/.local/bin"
    ];
    file.".ssh/authorized_keys".text = ''
      ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIAxccGxdfOFXeEClqz3ULl94ubzaJnk4pUus+ek18G0B tbarnouin@nixos
    '';
  };
  programs = {
    git = {
      enable = true;
    };
    vim = {
      enable = true;
      plugins = with pkgs.vimPlugins; [
        vim-airline
        vim-airline-themes
        vim-bufferline
        vim-markdown
        tabular
      ];
      settings = {
        expandtab = true;
        ignorecase = true;
        smartcase = true;
        number = true;
        shiftwidth = 2;
        tabstop = 2;
      };
      extraConfig = ''
        set nocompatible
        filetype on
        filetype plugin on
        filetype indent on
        syntax on
        set nobackup
        set showcmd
        set showmode
        set showmatch
        set hlsearch
        set wrap
        set linebreak
        set textwidth=0
        set wrapmargin=0
        set scrolloff=15

        highlight ExtraWhitespace ctermbg=red guibg=red
        autocmd BufWritePre * :%s/\s\+$//e

        inoremap " ""<left>
        inoremap \' \'\'<left>
        inoremap ( ()<left>
        inoremap [ []<left>
        inoremap { {}<left>

        let g:vim_markdown_folding_disabled = 1
        let g:mkdp_auto_start = 1
        let g:mkdp_auto_close = 1
        let g:airline_theme='molokai'
      '';
    };
    zsh = {
      enable = true;
      shellAliases = {
        ll = "ls -l";
        lla = "ls -lah";
        terraform = "tofu";
        # Nixos
        update = "sudo nixos-rebuild switch";
        upgrade = "sudo nix-channel --update && sudo nixos-rebuild switch --upgrade";
      };
      oh-my-zsh = {
        enable = true;
        plugins = [
          "git"
          "terraform"
          "sudo"
          "docker"
          "pip"
          "python"
          "pyenv"
          "pipenv"
        ];
        theme = "bira";
      };
    };
    tmux = {
      enable = true;
      mouse = true;
    };
  };
}
